@@ -15,7 +15,7 @@ class ConfigValidation(Validation):
 	@property
 	def jsonSchema(self) -> dict:
 		schema = self._dirPath / 'schemas/config-schema.json'
-		return json.loads(schema.read_text())
+		return json.loads(schema.read_text(encoding='utf-8'))
 
 
 	@property
